# smb-gym
##### A Super Mario Bros Gym built without enabling custom levels and data injection
<img src="mario-blocks.png"
     alt="Mario Blocks"
     style="float: center; height: 150px; width: 150px;" />



#### Credits:
This project acts as a python bridge of `Mario-AI Framework`:
> [Mario-AI] framework was created by Ahmed Khalifa, based on the original Mario AI Framework by Sergey Karakovskiy, Noor Shaker, and Julian Togelius, which in turn was based on Infinite Mario Bros by Markus Persson.

This project inspired by `gym-super-mario-bros` by Kautenja
